@@ -5,6 +5,9 @@ from south.v2 import SchemaMigration
 from django.db import models
 
 class Migration(SchemaMigration):
+    depends_on = (
+        ('meta', '0001_initial'),
+    )
 
     def forwards(self, orm):
         
