@@ -83,6 +83,7 @@ class PhotoBatchEditForm(TendenciBaseForm):
             'is_public',
             'owner',
             'safetylevel',
+            'exif_data',
             'allow_anonymous_view',
             'status_detail',
             'status',
@@ -109,6 +110,7 @@ class PhotoEditForm(TendenciBaseForm):
         fields = (
             'title',
             'caption',
+            'photographer',
             'license',
             'tags',
             'group',
@@ -123,6 +125,7 @@ class PhotoEditForm(TendenciBaseForm):
                       'fields': [
                           'title',
                           'caption',
+                          'photographer',
                           'tags',
                           'group',
                           'license',
