@@ -1,3 +1,5 @@
+import subprocess
+
 from django.core.management.base import BaseCommand
 from django.core.management import call_command
 from django.conf import settings
@@ -11,7 +13,6 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         from tendenci.core.site_settings.utils import get_setting
 
-        call_command('collect_metrics')
         call_command('expire_jobs')
         call_command('expire_resumes')
         call_command('expire_stories')
@@ -22,9 +23,12 @@ class Command(BaseCommand):
         call_command('refresh_membership_groups')
         call_command('send_corp_membership_notices')
         call_command('clean_old_exports')
-        call_command('update_dashboard_stats')
         call_command('delete_soft_deleted_items')
 
+        # Use Popen for longrunning tasks with heavy queries.
+        subprocess.Popen(['python', 'manage.py', 'update_dashboard_stats'])
+        subprocess.Popen(['python', 'manage.py', 'collect_metrics'])
+
         if all([get_setting('module', 'recurring_payments', 'enabled'),
                 getattr(settings, 'MERCHANT_LOGIN', ''),
                 getattr(settings, 'MERCHANT_TXN_KEY', '')
