@@ -14,6 +14,12 @@ from django.core.files.storage import default_storage
 from django.contrib.humanize.templatetags.humanize import intcomma
 from django.template.loader import get_template
 from django.template import TemplateDoesNotExist
+from django.contrib.admin.util import NestedObjects
+from django.utils.html import escape
+from django.utils.safestring import mark_safe
+from django.utils.text import capfirst
+from django.utils.encoding import force_unicode
+from django.db import router
 
 from simple_salesforce import Salesforce
 
@@ -39,6 +45,47 @@ STOP_WORDS = ['able','about','across','after','all','almost','also','am',
 template_directory = "templates"
 THEME_ROOT = get_theme_root()
 
+def get_deleted_objects(obj, user):
+    """
+    Find all objects related to ``obj`` that should also be deleted. 
+
+    Returns a nested list of strings suitable for display in the
+    template with the ``unordered_list`` filter.
+    
+    Copied and updated from django.contrib.admin.util for front end display.
+
+    """
+    using = router.db_for_write(obj.__class__)
+    collector = NestedObjects(using=using)
+    collector.collect([obj])
+    perms_needed = set()
+
+    def format_callback(obj):
+        opts = obj._meta
+
+        if hasattr(obj, 'get_absolute_url'):
+            url = obj.get_absolute_url()
+            p = '%s.%s' % (opts.app_label,
+                           opts.get_delete_permission())
+            if not user.has_perm(p):
+                perms_needed.add(opts.verbose_name)
+            # Display a link to the admin page.
+            return mark_safe(u'%s: <a href="%s">%s</a>' %
+                             (escape(capfirst(opts.verbose_name)),
+                              url,
+                              escape(obj)))
+        else:
+            # no link
+            return u'%s: %s' % (capfirst(opts.verbose_name),
+                                force_unicode(obj))
+
+    to_delete = collector.nested(format_callback)
+
+    protected = [format_callback(obj) for obj in collector.protected]
+
+    return to_delete, perms_needed, protected
+
+
 # this function is not necessary - datetime.now() *is* localized in django
 def now_localized():
     from timezones.utils import adjust_datetime_to_timezone
